=========
Community
=========

.. todo:: 

    This is just a placeholder page to explain the use and development of rasterio.

    If you have a project that uses rasterio, please contact us at https://github.com/mapbox/rasterio/issues     
    
Who is using rasterio?
----------------------

* The `Conservation Biology Institute`_ uses rasterio to provide `geoprocessing of NetCDF files`_.
* `Mapbox`_ uses rasterio to process satellite imagery for it's global satellite base maps.
* Mary Marek-Spartz's masters thesis compares the map algebra tools of the proprietary ESRI ArcPy library and the open source Rasterio library.  https://github.com/alfalimajuliett/masters-thesis

Software built on rasterio
--------------------------

The following software projects use rasterio

* pyimpute
* rasterstats

Rio plugins
------------

In addition to the core ``rio`` commands, visit the `Rio plugin registry`_ for a list of external plugins. 


.. include:: ../AUTHORS.txt


.. include:: ../CODE_OF_CONDUCT.txt

.. _Mapbox: https://mapbox.com
.. _Rio plugin registry: https://github.com/mapbox/rasterio/wiki/Rio-plugin-registry
.. _Conservation Biology Institute: http://consbio.org/
.. _geoprocessing of NetCDF files: https://github.com/consbio/clover
